@@ -1,5 +1,5 @@
 from greedypermutation.point import Point
 # from greedypermutation.metricspace import MetricSpace
-from greedypermutation.clustergraph import Cluster, ClusterGraph
+from greedypermutation.neighborgraph import Cell, NeighborGraph
 from greedypermutation.knnsample import knnsample
 from greedypermutation.greedytree import GreedyTree
